==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudformation/kotlin/outputs/StackSetOperationPreferences.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudformation.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property failureToleranceCount The number of accounts, per Region, for which this operation can fail before AWS CloudFormation stops the operation in that Region.
 * @property failureTolerancePercentage The percentage of accounts, per Region, for which this stack operation can fail before AWS CloudFormation stops the operation in that Region.
 * @property maxConcurrentCount The maximum number of accounts in which to perform this operation at one time.
 * @property maxConcurrentPercentage The maximum percentage of accounts in which to perform this operation at one time.
 * @property regionConcurrencyType The concurrency type of deploying StackSets operations in Regions, could be in parallel or one Region at a time.
 * @property regionOrders The order of the Regions in where you want to perform the stack operation.
 */
public data class StackSetOperationPreferences(
    public val failureToleranceCount: Int? = null,
    public val failureTolerancePercentage: Int? = null,
    public val maxConcurrentCount: Int? = null,
    public val maxConcurrentPercentage: Int? = null,
    public val regionConcurrencyType: String? = null,
    public val regionOrders: List<String>? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.cloudformation.outputs.StackSetOperationPreferences):
            StackSetOperationPreferences = StackSetOperationPreferences(
            failureToleranceCount = javaType.failureToleranceCount().map({ args0 -> args0 }).orElse(null),
            failureTolerancePercentage = javaType.failureTolerancePercentage().map({ args0 ->
                args0
            }).orElse(null),
            maxConcurrentCount = javaType.maxConcurrentCount().map({ args0 -> args0 }).orElse(null),
            maxConcurrentPercentage = javaType.maxConcurrentPercentage().map({ args0 -> args0 }).orElse(null),
            regionConcurrencyType = javaType.regionConcurrencyType().map({ args0 -> args0 }).orElse(null),
            regionOrders = javaType.regionOrders().map({ args0 -> args0 }),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudformation/kotlin/outputs/StackSetOperationPreferences.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudformation.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property failureToleranceCount The number of accounts, per Region, for which this operation can fail before AWS CloudFormation stops the operation in that Region.
 * @property failureTolerancePercentage The percentage of accounts, per Region, for which this stack operation can fail before AWS CloudFormation stops the operation in that Region.
 * @property maxConcurrentCount The maximum number of accounts in which to perform this operation at one time.
 * @property maxConcurrentPercentage The maximum percentage of accounts in which to perform this operation at one time.
 * @property regionConcurrencyType The concurrency type of deploying StackSets operations in Regions, could be in parallel or one Region at a time.
 * @property regionOrders The order of the Regions in where you want to perform the stack operation.
 */
public data class StackSetOperationPreferences(
    public val failureToleranceCount: Int? = null,
    public val failureTolerancePercentage: Int? = null,
    public val maxConcurrentCount: Int? = null,
    public val maxConcurrentPercentage: Int? = null,
    public val regionConcurrencyType: String? = null,
    public val regionOrders: List<String>? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.cloudformation.outputs.StackSetOperationPreferences): StackSetOperationPreferences = StackSetOperationPreferences(
            failureToleranceCount = javaType.failureToleranceCount().map({ args0 -> args0 }).orElse(null),
            failureTolerancePercentage = javaType.failureTolerancePercentage().map({ args0 ->
                args0
            }).orElse(null),
            maxConcurrentCount = javaType.maxConcurrentCount().map({ args0 -> args0 }).orElse(null),
            maxConcurrentPercentage = javaType.maxConcurrentPercentage().map({ args0 -> args0 }).orElse(null),
            regionConcurrencyType = javaType.regionConcurrencyType().map({ args0 -> args0 }).orElse(null),
            regionOrders = javaType.regionOrders().map({ args0 -> args0 }),
        )
    }
}
